@@ -8,7 +8,7 @@ from typing import Any, Callable, Iterator, Optional, TextIO
 
 from eduvpn_common.main import EduVPN, ServerType, WrappedError
 from eduvpn_common.state import State, StateType
-from eduvpn_common.types import ProxySetup, ReadRxBytes, RefreshList  # type: ignore[attr-defined]
+from eduvpn_common.types import ProxySetup, ReadRxBytes  # type: ignore[attr-defined]
 
 from eduvpn import nm
 from eduvpn.config import Configuration
@@ -145,7 +145,6 @@ class ApplicationModel:
         self.nm_manager = nm_manager
         self._was_tcp = False
         self._should_failover = False
-        self._refresh_list_handler = RefreshList(self.refresh_list)
         self._proxy_setup_handler = ProxySetup(self.on_proxy_setup)
 
     @property
@@ -162,10 +161,8 @@ class ApplicationModel:
     def refresh_list(self):
         set_server_list_refresh(self.common, self.server_db.configured)
 
-    def register(self, debug: bool):
-        self.common.register(debug=debug)
-        if self.variant.use_predefined_servers:
-            self.common.discovery_startup(self._refresh_list_handler)  # type: ignore[attr-defined]
+    def register(self):
+        self.common.register()
         self.common.set_token_handler(self.load_tokens, self.save_tokens)
 
     def cancel(self):
@@ -257,6 +254,13 @@ class ApplicationModel:
         self.cancel()
         self.common.set_state(State.MAIN)
 
+    def delisted_disco(self):
+        self.server_db.disco_update(search="", cache=False)
+
+        # refresh the server list if we're still in the main state
+        if self.common.in_state(State.MAIN):
+            self.refresh_list()
+
     def add(self, server, callback=None):
         self.common.add_server(server.category_id, server.identifier)
         if callback:
@@ -412,11 +416,12 @@ class ApplicationModel:
                 self.common.set_state(State.CONNECTING)
             connection = Connection.parse(config)
             proxy = None
-            if config.proxy is not None:
+            if config.protocol is Protocol.WIREGUARDTCP:
+                proxy = Proxy(self.common, connection.proxy_endpoint)
                 wrapper_proxy = self.common.new_proxyguard(
-                    config.proxy.listen_port, config.proxy.source_port, config.proxy.peer, self._proxy_setup_handler
+                    proxy.listen_port, proxy.source_port, proxy.endpoint, self._proxy_setup_handler
                 )
-                proxy = Proxy(self.common, config.proxy, wrapper_proxy)
+                proxy.wrapper = wrapper_proxy
             connection.connect(
                 self.nm_manager,
                 config.default_gateway,
