@@ -563,7 +563,10 @@ class CommandLine:
         command = ""
         while command != "quit":
             # Ask for the command to execute
-            command = input(f"[{self.name}]: ")
+            try:
+                command = input(f"[{self.name}]: ")
+            except EOFError:
+                command = "quit"
 
             # Update the state right before we execute
             self.update_state()
@@ -679,7 +682,7 @@ class CommandLine:
         self.skip_yes = parsed.yes
 
         # Register the common library
-        self.app.model.register(parsed.debug)
+        self.app.model.register()
 
         # Update the state by asking NetworkManager
         self.update_state(True)
