@@ -78,7 +78,7 @@ class ConnectionState(enum.Enum):
             raise ValueError(state)
 
 
-def find_free_udp_port(exclude_port):
+def find_free_udp_port_exclude(exclude_port):
     max_retries = 10
     retries = 0
     while retries < max_retries:
@@ -115,11 +115,11 @@ class NMManager:
         return self._client is not None
 
     @run_in_background_thread("proxyguard-tunnel")
-    def proxy_tunnel(self, listen_port):
+    def proxy_tunnel(self, wg_listen_port):
         assert self.proxy is not None
-        _logger.debug(f"tunneling proxyguard with listen port: {listen_port}")
+        _logger.debug(f"tunneling proxyguard with WG listen port: {wg_listen_port}")
         try:
-            self.proxy.tunnel(listen_port)
+            self.proxy.tunnel(wg_listen_port)
         except Exception as e:
             self.proxy.forward_exception(e)
 
@@ -534,6 +534,12 @@ class NMManager:
         # https://lazka.github.io/pgi-docs/NM-1.0/classes/WireGuardPeer.html#NM.WireGuardPeer
         peer = NM.WireGuardPeer.new()
         wg_endpoint = config["Peer"]["Endpoint"]
+
+        if proxy is not None:
+            if wg_endpoint != "":
+                _logger.warning(f"ignoring WireGuard endpoint: {wg_endpoint} as we have to use ProxyGuard")
+            wg_endpoint = f"127.0.0.1:{proxy.listen_port}"
+
         peer.set_endpoint(wg_endpoint, allow_invalid=False)
 
         psk = config["Peer"].get("PresharedKey")
@@ -596,19 +602,19 @@ class NMManager:
 
         # we set some sensible default with an override using EDUVPN_WG_FWMARK
         fwmark = int(os.environ.get("EDUVPN_WG_FWMARK", 51860))
-        listen_port = int(os.environ.get("EDUVPN_WG_LISTEN_PORT", 0))
+        wg_listen_port = int(os.environ.get("EDUVPN_WG_LISTEN_PORT", 0))
 
         # if we are using proxyguard we need to know the port beforehand
         # just get an available port
         # Yes, this can race but there is not other option right now
         # the NM API just gives port 0 from device.get_listen_port()
-        if proxy is not None and listen_port == 0:
-            listen_port = find_free_udp_port(proxy.peer_port)
+        if proxy is not None and wg_listen_port == 0:
+            wg_listen_port = find_free_udp_port_exclude(proxy.listen_port)
 
         s_ip4.set_property(NM.SETTING_IP_CONFIG_ROUTE_TABLE, fwmark)
         s_ip6.set_property(NM.SETTING_IP_CONFIG_ROUTE_TABLE, fwmark)
         w_con.set_property(NM.DEVICE_WIREGUARD_FWMARK, fwmark)
-        w_con.set_property(NM.DEVICE_WIREGUARD_LISTEN_PORT, listen_port)
+        w_con.set_property(NM.DEVICE_WIREGUARD_LISTEN_PORT, wg_listen_port)
 
         # The routing that is done by NM by default doesn't cut it
         # It automatically adds a suppress prefixlength rule such that LAN traffic is allowed
@@ -682,7 +688,7 @@ class NMManager:
 
         def set_callback(success: bool):
             if success and proxy is not None:
-                self.proxy_tunnel(listen_port)
+                self.proxy_tunnel(wg_listen_port)
             if callback is not None:
                 callback(success)
 
@@ -994,7 +1000,7 @@ def action_with_mainloop(action: Callable):
     main_loop.run()
 
 
-def add_connection_callback(client: NM.Client, result: Task, user_data) -> None:
+def add_connection_callback(client: "NM.Client", result: Task, user_data) -> None:
     object, c, callback = user_data
     try:
         new_con = client.add_connection_finish(result)
