@@ -1,9 +1,25 @@
+from contextlib import closing
+from socket import AF_INET, SOCK_DGRAM, SOCK_STREAM, socket
 from typing import List
 from urllib.parse import urlparse
 
 from eduvpn.utils import handle_exception
 
 
+def find_free_udp_port():
+    with closing(socket(AF_INET, SOCK_DGRAM)) as s:
+        s.bind(("", 0))
+        port = s.getsockname()[1]
+        return port
+
+
+def find_free_tcp_port():
+    with closing(socket(AF_INET, SOCK_STREAM)) as s:
+        s.bind(("", 0))
+        port = s.getsockname()[1]
+        return port
+
+
 class Proxy:
     """The class that represents a proxyguard instance
     :param: common: The common library
@@ -14,12 +30,13 @@ class Proxy:
     def __init__(
         self,
         common,
-        config,
-        wrapper,
+        endpoint,
     ):
         self.common = common
-        self.config = config
-        self.wrapper = wrapper
+        self.endpoint = endpoint
+        self.wrapper = None
+        self._cached_source_port = None
+        self._cached_listen_port = None
 
     def forward_exception(self, error):
         handle_exception(self.common, error)
@@ -30,17 +47,17 @@ class Proxy:
     def restart(self):
         self.wrapper.restart()
 
-    @property
-    def peer(self) -> str:
-        return self.config.peer
-
     @property
     def source_port(self) -> int:
-        return self.config.source_port
+        if self._cached_source_port is None:
+            self._cached_source_port = find_free_tcp_port()
+        return self._cached_source_port
 
     @property
     def listen_port(self) -> int:
-        return self.config.listen_port
+        if self._cached_listen_port is None:
+            self._cached_listen_port = find_free_udp_port()
+        return self._cached_listen_port
 
     @property
     def peer_ips(self) -> List[str]:
@@ -49,7 +66,7 @@ class Proxy:
     @property
     def peer_scheme(self) -> str:
         try:
-            parsed = urlparse(self.config.peer)
+            parsed = urlparse(self.endpoint)
             return parsed.scheme
         except Exception:
             return ""
