@@ -250,14 +250,14 @@ class EduVpnGtkWindow(Gtk.ApplicationWindow):
         self.create_error_revealer()
 
         # exit window on ctrl+q keyboard shortcut
-        accel = Gtk.AccelGroup()
+        accel = Gtk.AccelGroup()  # type: ignore[attr-defined]
         accel.connect(
             Gdk.keyval_from_name("q"),
             Gdk.ModifierType.CONTROL_MASK,
-            Gtk.AccelFlags.VISIBLE,
+            Gtk.AccelFlags.VISIBLE,  # type: ignore[attr-defined]
             self.on_close_window_shortcut,
         )
-        self.add_accel_group(accel)
+        self.add_accel_group(accel)  # type: ignore[attr-defined]
 
         self.add_custom_server_button_container = builder.get_object("addCustomServerRow")
         self.add_other_server_button_container = builder.get_object("addOtherServerRow")
@@ -279,6 +279,7 @@ class EduVpnGtkWindow(Gtk.ApplicationWindow):
         self.connection_validity_thread_cancel: Optional[Callable] = None
         self.connection_info_stats = None
         self.current_shown_page = None
+        self.load_disco_server_page = self.app.variant.use_predefined_servers
 
         self.disable_loading_page = False
 
@@ -351,7 +352,7 @@ class EduVpnGtkWindow(Gtk.ApplicationWindow):
             try:
                 self.common.register_class_callbacks(self)
                 self.enter_deregistered()
-                self.app.model.register(debug=self.eduvpn_app.debug)
+                self.app.model.register()
                 self.exit_deregistered()
                 self.app.initialize_network()
             except Exception as e:
@@ -817,8 +818,11 @@ For detailed information, see the log file located at:
         if not servers:
             self.enter_search(True)
 
-        # show keyring dialog if it's not secure
+        if self.load_disco_server_page:
+            self.load_disco_server_page = False
+            self.call_model("delisted_disco")
 
+        # show keyring dialog if it's not secure
         if self.app.model.keyring.secure:
             return
 
@@ -1074,6 +1078,7 @@ For detailed information, see the log file located at:
     def enter_server_list_refresh(self, _old_state, servers) -> None:
         logger.debug("server list refresh")
         if self.is_searching_server:
+            logger.debug("not refreshing configured server list as we're searching a server")
             return
 
         search.update_results(self, servers)
@@ -1122,10 +1127,9 @@ For detailed information, see the log file located at:
         def on_added(server):
             logger.debug(f"Server added, {str(server)}")
 
-        self.show_loading_page("Loading", "Server is loading...")
-
         if self.is_searching_server:
             self.is_searching_server = False
+            self.show_loading_page("Loading", "Server is loading...")
             self.call_model("add", server, on_added)
             self.exit_search()
         else:
@@ -1134,6 +1138,7 @@ For detailed information, see the log file located at:
                     f"Server is no longer available: {str(server)}. Please contact your IT department"
                 )
                 return
+            self.show_loading_page("Loading", "Server is loading...")
             self.call_model("connect", server)
 
     def server_ask_remove(self, server):
