@@ -64,9 +64,48 @@ EOF
     exit 0
 }
 
+install_alma() {
+    if [ "${VERSION/.*/}" != "9" ]; then
+	echo "$PRETTY_NAME is not supported"
+	exit 1
+    fi
+    set -x
+    curl -O https://app.eduvpn.org/linux/v4/rpm/app+linux@eduvpn.org.asc
+    sudo rpm --import app+linux@eduvpn.org.asc
+    cat << 'EOF' | sudo tee /etc/yum.repos.d/python-eduvpn-client_v4.repo
+[python-eduvpn-client_v4]
+name=eduVPN for Linux 4.x (AlmaLinux 9)
+baseurl=https://app.eduvpn.org/linux/v4/rpm/alma+epel-9-$basearch
+gpgcheck=1
+EOF
+sudo dnf install epel-release
+sudo dnf install eduvpn-client
+exit 0
+}
+
+install_rocky() {
+    if [ "${VERSION/.*/}" != "9" ]; then
+	echo "$PRETTY_NAME is not supported"
+	exit 1
+    fi
+    set -x
+    curl -O https://app.eduvpn.org/linux/v4/rpm/app+linux@eduvpn.org.asc
+    sudo rpm --import app+linux@eduvpn.org.asc
+    cat << 'EOF' | sudo tee /etc/yum.repos.d/python-eduvpn-client_v4.repo
+[python-eduvpn-client_v4]
+name=eduVPN for Linux 4.x (Rocky Linux 9)
+baseurl=https://app.eduvpn.org/linux/v4/rpm/rocky+epel-9-$basearch
+gpgcheck=1
+EOF
+sudo dnf install epel-release
+sudo dnf install eduvpn-client
+exit 0
+}
+
+
 case $VERSION_CODENAME in
-    # ubuntu versions
-    "focal" | "jammy" | "noble" | "plucky" | "bullseye" | "bookworm")
+    # ubuntu and deb versions
+    "jammy" | "noble" | "plucky" | "bookworm" | "trixie")
 	install_deb "$VERSION_CODENAME"
 	;;
     # For linux mint we need to do some redirections to ubuntu codenames
@@ -93,6 +132,12 @@ case $NAME in
     "CentOS Stream")
 	install_centos
 	;;
+    "AlmaLinux")
+    install_alma
+    ;;
+    "Rocky Linux")
+    install_rocky
+    ;;
     *)
 	echo "OS: \"$NAME\" with codename \"$VERSION_CODENAME\" is not supported"
 	exit 1
